@@ -12,6 +12,7 @@ from iker.common.utils.jsonutils import JsonType
 from iker.common.utils.randutils import randomizer
 from sqlmodel import Field, SQLModel
 
+from plexus.common.utils.apiutils import managed_db_session
 from plexus.common.utils.ormutils import (
     db_activate_revision_model,
     db_activate_snapshot_model,
@@ -954,7 +955,7 @@ def test_make_snapshot_model_trigger(fixture_postgresql_test_proc, fixture_postg
                 dummy_json=rng.random_json_object(5),
             )
 
-    with maker.make_session() as session:
+    with maker.make_session() as session, managed_db_session(session):
         session.execute(sa.sql.text("SET TIMEZONE TO 'UTC'"))
         session.commit()
 
@@ -1040,7 +1041,7 @@ def test_make_revision_model_trigger(fixture_postgresql_test_proc, fixture_postg
                 dummy_json=rng.random_json_object(5),
             )
 
-    with maker.make_session() as session:
+    with maker.make_session() as session, managed_db_session(session):
         session.execute(sa.sql.text("SET TIMEZONE TO 'UTC'"))
         session.commit()
 
